/****************************************************************************
** Meta object code from reading C++ file 'hierarchyentry.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../cantor-26.07.90/src/hierarchyentry.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'hierarchyentry.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14HierarchyEntryE_t {};
} // unnamed namespace

template <> constexpr inline auto HierarchyEntry::qt_create_metaobjectdata<qt_meta_tag_ZN14HierarchyEntryE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "HierarchyEntry",
        "hierarhyEntryNameChange",
        "",
        "name",
        "searchName",
        "depth",
        "evaluate",
        "WorksheetEntry::EvaluationOption",
        "evalOp",
        "updateEntry",
        "populateMenu",
        "QMenu*",
        "menu",
        "QPointF",
        "pos",
        "handleControlElementDoubleClick",
        "updateAfterSettingsChanges",
        "setLevelTriggered",
        "QAction*"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'hierarhyEntryNameChange'
        QtMocHelpers::SignalData<void(QString, QString, int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 4 }, { QMetaType::Int, 5 },
        }}),
        // Slot 'evaluate'
        QtMocHelpers::SlotData<bool(WorksheetEntry::EvaluationOption)>(6, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Slot 'evaluate'
        QtMocHelpers::SlotData<bool()>(6, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool),
        // Slot 'updateEntry'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'populateMenu'
        QtMocHelpers::SlotData<void(QMenu *, QPointF)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 }, { 0x80000000 | 13, 14 },
        }}),
        // Slot 'handleControlElementDoubleClick'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateAfterSettingsChanges'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setLevelTriggered'
        QtMocHelpers::SlotData<void(QAction *)>(17, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 18, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<HierarchyEntry, qt_meta_tag_ZN14HierarchyEntryE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject HierarchyEntry::staticMetaObject = { {
    QMetaObject::SuperData::link<WorksheetEntry::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14HierarchyEntryE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14HierarchyEntryE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14HierarchyEntryE_t>.metaTypes,
    nullptr
} };

void HierarchyEntry::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<HierarchyEntry *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->hierarhyEntryNameChange((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 1: { bool _r = _t->evaluate((*reinterpret_cast<std::add_pointer_t<WorksheetEntry::EvaluationOption>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 2: { bool _r = _t->evaluate();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 3: _t->updateEntry(); break;
        case 4: _t->populateMenu((*reinterpret_cast<std::add_pointer_t<QMenu*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[2]))); break;
        case 5: _t->handleControlElementDoubleClick(); break;
        case 6: _t->updateAfterSettingsChanges(); break;
        case 7: _t->setLevelTriggered((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QMenu* >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (HierarchyEntry::*)(QString , QString , int )>(_a, &HierarchyEntry::hierarhyEntryNameChange, 0))
            return;
    }
}

const QMetaObject *HierarchyEntry::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *HierarchyEntry::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14HierarchyEntryE_t>.strings))
        return static_cast<void*>(this);
    return WorksheetEntry::qt_metacast(_clname);
}

int HierarchyEntry::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = WorksheetEntry::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void HierarchyEntry::hierarhyEntryNameChange(QString _t1, QString _t2, int _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3);
}
QT_WARNING_POP
